use 5.008004;
use ExtUtils::MakeMaker;
use English;

#< get the perl path, copied from man perlvar
use Config;
my $secure_perl_path = $Config{perlpath};
if ($^O ne 'VMS') {
    $secure_perl_path .= $Config{_exe} unless
	$secure_perl_path =~ m/$Config{_exe}$/i;
}
#>

my %prereq = (BerkeleyDB => 0,
	      MLDBM => 0);
#< install prerequisites
my %failmessage = (BerkeleyDB => "\nThis BerkeleyDB perl module install will have failed if you did not have \nBerkeley DB itself installed, with much garbage following the error,\n   \"db.h is not for Berkeley DB at all\".  \nYou can get and install Berkeley DB from http://www.sleepycat.com/ or you can \nlook for a package for your architecture there.  Under Debian, you can simply \n   apt-get install libberkeleydb-perl \nas root.  You will also want to install MLDBM:\n   apt-get install libmldbm-perl",
		   MLDBM => "I have successfully installed MLDBM from CPAN, and you may find a package for \nyour architecture.  For Debian the package is called libmldbm-perl.",
		   );

my $pwd = `pwd`;
chomp $pwd;
unshift @INC, "$pwd/blib/lib", "$pwd/lib";
for my $dep (keys %prereq) {
    if (eval "require($dep)") {
	print "$dep ok\n";
    } else {
	my ($dir) = reverse sort glob(qq(packages/$dep-*));
	print "trying to build $dep from $dir to $dest\n";
	chdir $dir;
	system(qq(perl Makefile.PL; make test))
	    and die "$@\nfailed to install the missing dependency $dep: \n$failmessage{$dep}\n";
	chdir $pwd;
	my @stack = (qq($dir/blib));
	while (@stack) {
	    my $item = pop @stack; 
	    my $dest = $item;
	    $dest =~ s|^\Q$dir\E|$pwd/|g;
	    if (-d $item) {
		opendir(D, $item) or die "cannot read $item: $!\n";
		push @stack, map {qq($item/$_)} grep /[^\.]/, readdir D;
		closedir D;
		mkdir $dest unless -d $dest;
	    } else {
		system(qq(cp $item $dest)) 
		    and die "cannot cp [$item] [$dest]: $@\n";
	    }
	}
    }
}
#>

my $dbmfile = '$(INST_LIBDIR)/unigram-doc-counts-AQUAINT.dbm';

# See lib/ExtUtils/MakeMaker.pm for details of how to influence
# the contents of the Makefile that is written.
WriteMakefile(
	      NAME => 'Nuggeteer',
#	      VERSION_FROM => 'src/nuggeteer.pl', # finds $VERSION
	      VERSION => 0.5,
	      PREREQ_FATAL => 1,
	      PREREQ_PM => {%prereq, 
			"porter"}, # e.g., Module::Name => 1.1
	      PM => { 'lib/Idf.pm' => '$(INST_LIBDIR)/Idf.pm',
		      'lib/porter.pm' => '$(INST_LIBDIR)/porter.pm',
		      'nuggeteer.pl' => '$(INST_SCRIPT)/nuggeteer.pl',
		      'genstats.pl' => '$(INST_SCRIPT)/genstats.pl',
		      'extractpernid.pl' => '$(INST_SCRIPT)/extractpernid.pl',
		      'cdft' => '$(INST_BIN)/cdft'
		  },
	      clean => {FILES => 'genstats.pl nuggeteer.pl lib/makedbm.pl t/test-bigrams-0.15-c.out t/test-exact.out t/test-MITCSAIL.c-unknowns cdft extractpernid.pl'},
	      depend => { 'lib/Idf.pm' => $dbmfile,
		         },

    ($] >= 5.005 ?     ## Add these new keywords supported since 5.005
      (ABSTRACT_FROM  => 'src/nuggeteer.pl', # retrieve abstract from module
       AUTHOR         => 'Gregory Adam Marton <gremio@mit.edu>') : ()),
);

sub MY::postamble {
    return <<"MAKE_FRAG";
$dbmfile: lib/unigram-doc-counts-AQUAINT.txt lib/makedbm.pl
	\@mkdir -p \$(INST_LIBDIR)
	\@echo "Building the unigram hash may take 5 to 10 minutes:"
	lib/makedbm.pl \$< $dbmfile

nuggeteer.pl: src/nuggeteer.pl
	perl -p -e 's|^\\\#! \\S* perl \\s -w \\s* \$ |\\\#!$secure_perl_path -w\\n|x;' src/nuggeteer.pl > nuggeteer.pl
	\@chmod +x nuggeteer.pl

genstats.pl: src/genstats.pl cdft
	perl -p -e 's|^\\\#! \\S* perl \\s -w \\s* \$ |\\\#!$secure_perl_path -w\\n|x;' src/genstats.pl > genstats.pl
	\@chmod +x genstats.pl

lib/makedbm.pl: src/makedbm.pl
	perl -p -e 's|^\\\#! \\S* perl \\s -w \\s* \$ |\\\#!$secure_perl_path -w\\n|x;' src/makedbm.pl > lib/makedbm.pl
	\@chmod +x lib/makedbm.pl

cdft: src/cdft.c
	gcc -lm -O -o cdft src/cdft.c

extractpernid.pl: src/extractpernid.pl
	perl -p -e 's|^\\\#! \\S* perl \\s -w \\s* \$ |\\\#!$secure_perl_path -w\\n|x;' src/extractpernid.pl > extractpernid.pl
	\@chmod +x extractpernid.pl


MAKE_FRAG
    ;
}
