#!/usr/bin/perl -w

use strict;
use Carp;
use Data::Dumper;
use Getopt::Long;
use BerkeleyDB;
use MLDBM qw(BerkeleyDB::Hash Storable);
#< documentation
use constant VERSION => q$Id: pl.tmpl,v 1.3 2004/07/16 17:19:32 gremio Exp $.$/;
use constant USAGE => <<"EOT"
usage: $0 textfile dbmfile
EOT
    ;
=pod

=head1 NAME

makedbm - make a single-layer mldbm hash out of a tab-delimited two-column text file

=head1 SYNOPSYS

makedbm.pl textfile dbmfile

=head1 DESCRIPTION

Given an input text with two columns: 
  a1 \t b1 \n
  a2 \t b2 \n
  a3 \t b3 \n
  ...
create a dbm of the form: 
  dbm = { a1 => b1, 
          a2 => b2,
          a3 => b3 }
replacing any duplicate keys. 

=head1 NOTES

=head1 SEE ALSO

=head1 BUGS

=cut
    ;
#> 

GetOptions ("help" => sub {exec qq(perldoc $0);},
	    "Version" => sub {print VERSION;exit 0;},
	    ) or die USAGE;

my $dbmfile = pop @ARGV;
die USAGE unless @ARGV;
unlink $dbmfile if -e $dbmfile;
my $db = createdb($dbmfile);

while (<>) {
    next if /^\#/ or !/\S/;
    if (/^([^\t]*)\t([^\n]*)\n$/) {
	$db->{$1} = $2;
    } else {
	warn "unexpected format [$_] at line $.\n";
    }
}

sub createdb {
    my $file = shift;
    my %h = ();
    unlink($file);
    tie(%h, "MLDBM",
	-Filename => $file,
	-Flags    => DB_CREATE)
	or die "Cannot open file $file: $! $BerkeleyDB::Error\n" ;
    return \%h;
}

1;

